visit_nodes_with_custom

Function visit_nodes_with_custom 

pub fn visit_nodes_with_custom<V, C, CW>(nodes: &mut [Node<C>], visitor: V) -> V
where C: CustomNode, V: Visitor<C> + VisitMut, CW: CustomNodeWalker<Custom = C>,
Visitor entrypoint. Visit nodes in array calling visitor methods. Recursively visit nodes in children, and attributes. Provide custom handler that is used to visit custom nodes. Custom handler should return true if visitor should continue to traverse, and call visitor methods for its children.

Return modified visitor back